@@ -4,15 +4,17 @@ import (
 	"bytes"
 	"encoding/json"
 	"io/ioutil"
+	"os"
 	"path/filepath"
 	"testing"
 
-	"github.com/containers/image/v4/directory"
-	"github.com/containers/image/v4/docker"
+	"github.com/containers/image/v5/directory"
+	"github.com/containers/image/v5/docker"
 	"github.com/pkg/errors"
+
 	// this import is needed  where we use the "atomic" transport in TestPolicyUnmarshalJSON
-	_ "github.com/containers/image/v4/openshift"
-	"github.com/containers/image/v4/types"
+	_ "github.com/containers/image/v5/openshift"
+	"github.com/containers/image/v5/types"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -92,33 +94,88 @@ func TestDefaultPolicyPath(t *testing.T) {
 	const nondefaultPath = "/this/is/not/the/default/path.json"
 	const variableReference = "$HOME"
 	const rootPrefix = "/root/prefix"
+	oldHomeEnv, hasHomeEnv := os.LookupEnv("HOME")
+	tempHome, err := ioutil.TempDir("", "tempHome")
+	require.NoError(t, err)
+	err = os.Setenv("HOME", tempHome)
+	require.NoError(t, err)
+	defer func() {
+		os.RemoveAll(tempHome)
+		if hasHomeEnv {
+			os.Setenv("HOME", oldHomeEnv)
+		} else {
+			os.Unsetenv("HOME")
+		}
+	}()
+	userDefaultPolicyPath := filepath.Join(tempHome, userPolicyFile)
 
 	for _, c := range []struct {
-		sys      *types.SystemContext
-		expected string
+		sys             *types.SystemContext
+		userfilePresent bool
+		expected        string
 	}{
 		// The common case
-		{nil, systemDefaultPolicyPath},
+		{nil, false, systemDefaultPolicyPath},
 		// There is a context, but it does not override the path.
-		{&types.SystemContext{}, systemDefaultPolicyPath},
+		{&types.SystemContext{}, false, systemDefaultPolicyPath},
 		// Path overridden
-		{&types.SystemContext{SignaturePolicyPath: nondefaultPath}, nondefaultPath},
+		{&types.SystemContext{SignaturePolicyPath: nondefaultPath}, false, nondefaultPath},
 		// Root overridden
 		{
 			&types.SystemContext{RootForImplicitAbsolutePaths: rootPrefix},
+			false,
 			filepath.Join(rootPrefix, systemDefaultPolicyPath),
 		},
+		// Empty context and user policy present
+		{&types.SystemContext{}, true, userDefaultPolicyPath},
+		// Only user policy present
+		{nil, true, userDefaultPolicyPath},
+		// Context signature path and user policy present
+		{
+			&types.SystemContext{
+				SignaturePolicyPath: nondefaultPath,
+			},
+			true,
+			nondefaultPath,
+		},
+		// Root and user policy present
+		{
+			&types.SystemContext{
+				RootForImplicitAbsolutePaths: rootPrefix,
+			},
+			true,
+			userDefaultPolicyPath,
+		},
+		// Context and user policy file preset simultaneously
+		{
+			&types.SystemContext{
+				RootForImplicitAbsolutePaths: rootPrefix,
+				SignaturePolicyPath:          nondefaultPath,
+			},
+			true,
+			nondefaultPath,
+		},
 		// Root and path overrides present simultaneously,
 		{
 			&types.SystemContext{
 				RootForImplicitAbsolutePaths: rootPrefix,
 				SignaturePolicyPath:          nondefaultPath,
 			},
+			false,
 			nondefaultPath,
 		},
 		// No environment expansion happens in the overridden paths
-		{&types.SystemContext{SignaturePolicyPath: variableReference}, variableReference},
+		{&types.SystemContext{SignaturePolicyPath: variableReference}, false, variableReference},
 	} {
+		if c.userfilePresent {
+			err := os.MkdirAll(filepath.Dir(userDefaultPolicyPath), os.ModePerm)
+			require.NoError(t, err)
+			f, err := os.Create(userDefaultPolicyPath)
+			require.NoError(t, err)
+			f.Close()
+		} else {
+			os.Remove(userDefaultPolicyPath)
+		}
 		path := defaultPolicyPath(c.sys)
 		assert.Equal(t, c.expected, path)
 	}
@@ -660,17 +717,17 @@ func TestNewPRSignedBy(t *testing.T) {
 	}, pr)
 
 	// Invalid keyType
-	pr, err = newPRSignedBy(sbKeyType(""), testPath, nil, testIdentity)
+	_, err = newPRSignedBy(sbKeyType(""), testPath, nil, testIdentity)
 	assert.Error(t, err)
-	pr, err = newPRSignedBy(sbKeyType("this is invalid"), testPath, nil, testIdentity)
+	_, err = newPRSignedBy(sbKeyType("this is invalid"), testPath, nil, testIdentity)
 	assert.Error(t, err)
 
 	// Both keyPath and keyData specified
-	pr, err = newPRSignedBy(SBKeyTypeGPGKeys, testPath, testData, testIdentity)
+	_, err = newPRSignedBy(SBKeyTypeGPGKeys, testPath, testData, testIdentity)
 	assert.Error(t, err)
 
 	// Invalid signedIdentity
-	pr, err = newPRSignedBy(SBKeyTypeGPGKeys, testPath, nil, nil)
+	_, err = newPRSignedBy(SBKeyTypeGPGKeys, testPath, nil, nil)
 	assert.Error(t, err)
 }
 
